@@ -11,3 +11,6 @@ class EventSubscriber:
 
     def get_handlers_names(self) -> List[str]:
         return [handler.__name__ for handler in self.handlers]
+
+    def __repr__(self):
+        return f"EventSubscriber ({self.event_name}.{self.event_version} -> {self.handlers})"
