@@ -41,6 +41,7 @@ from petisco.http.request_errors import (
     TimeoutRequestError,
     ConnectionRequestError,
     UnknownRequestError,
+    UnauthorizedRequestError,
 )
 from petisco.http.response import Response
 from petisco.logger.log_message import LogMessage
@@ -87,6 +88,9 @@ from petisco.event.legacy.subscriber.infrastructure.not_implemented_event_subscr
 )
 from petisco.event.shared.domain.event_subscriber import EventSubscriber
 from petisco.webhooks.webhook.domain.webhook import Webhook
+from petisco.webhooks.webhook.domain.webhook_id import WebhookId
+from petisco.webhooks.webhook.domain.webhook_sender import WebhookSender
+
 
 classes = [
     "IService",
@@ -148,9 +152,12 @@ classes = [
     "TimeoutRequestError",
     "ConnectionRequestError",
     "UnknownRequestError",
+    "UnauthorizedRequestError",
     "IEventBus",
     "event_handler",
     "Webhook",
+    "WebhookSender",
+    "WebhookId",
     "IEventChaos",
 ]
 
